[![PyPI version](https://badge.fury.io/py/rshanker779-common.svg)](https://badge.fury.io/py/rshanker779-common)

[![Build Status](https://travis-ci.com/rshanker779/rshanker779_common.svg?branch=master)](https://travis-ci.com/rshanker779/rshanker779_common)

[![Coverage Status](https://coveralls.io/repos/github/rshanker779/rshanker779_common/badge.svg?branch=master)](https://coveralls.io/github/rshanker779/rshanker779_common?branch=master)

Common utilities for my projects
